# 2022.12.0

**Released on December 21st, 2022**

[Documentation for this release](https://cotainr.readthedocs.org/en/2022.12.0/)

First public release.

## New features

- `cotainr info` command for showing system info
- `cotainr build` command for building containers
- HPC systems integration via `system.json` and `--system` CLI flag
- Conda environment use case support via `--conda-env` CLI flag
- Documentation hosted on https://cotainr.readthedocs.io
- LUMI ROCm PyTorch cotainr build example
